/****************************************************************
 *                                                              *
 *          S A S   I N S T A L L A T I O N   T E S T           *
 *                                                              *
 *    NAME: HPAINIT                                             *
 *   TITLE: Initialization program of HPA procedures            *
 * PRODUCT: HPA                                                 *
 *                                                              *
 * This file must be run prior to executing the HPA install     *
 * tests or HPA sample programs.                                *
 *                                                              *
 * You must input the correct values for your site for:         *
 *    GRIDHOST=, GRIDINSTALLLOC=, ENGINE=, USER=,               *
 *    PASSWORD=, and DATABASE=.                                 *
 *                                                              *
 * Additionally, if running on:                                 *
 *    Teradata Appliance,  input value for GRIDDATASERVER=.     *
 *    Greenplum Appliance, input value for SCHEMA=.             *
 *    SASHDAT:  input value for HDFS_PATH= or set to NULL.      *
 *                                                              *
 ****************************************************************/

%let GRIDHOST      =<YOUR SITE-SPECIFIC APPLIANCE HOST HERE>;
%let GRIDINSTALLLOC=<YOUR SITE-SPECIFIC INSTALL DIRECTORY HERE>;
%let ENGINE        =<YOUR SITE-SPECIFIC APPLIANCE: TERADATA or GREENPLM 
                     or SASHDAT>;
%let USER          =<YOUR SITE-SPECIFIC DATABASE USER ID>;
%let PASSWORD      =<YOUR SITE-SPECIFIC DATABASE PASSWORD>;
%let DATABASE      =<YOUR SITE-SPECIFIC DATABASE NAME>;

 /* enter for GRIDDATASERVER only if using a Teradata appliance */
%let GRIDDATASERVER=/*<YOUR SITE-SPECIFIC TERADATA DATASERVER>*/;

/* enter for SCHEMA only if using a Greenplum appliance */
%let SCHEMA=/*<YOUR SITE-SPECIFIC SCHEMA IF GREENPLUM APPLIANCE>*/;

/* enter for HDFS_PATH only if using sashdat */
%let HDFS_PATH=/*<YOUR SITE-SPECIFIC HDFS path>*/;


/********************************************************************/
/*           DO NOT MODIFY ANYTHING BELOW THIS LINE                 */
/********************************************************************/

 /*------------------------------------------------------------*/
 /*- Some cleanup code depending on what appliance is used    -*/
 /*------------------------------------------------------------*/

%macro appliance;
   %global SERVER;
   %if %upcase(&engine)=TERADATA %then %do;
      options set=GRIDDATASERVER="&GRIDDATASERVER";
      %let SERVER=SERVER="&GRIDHOST" USER=&USER PASSWORD=&PASSWORD DATABASE=&DATABASE;
      %let HDFS_PATH=;
   %end;

   %else %if %upcase(&engine)=GREENPLM %then %do;
      %let SERVER=SERVER="&GRIDHOST" USER=&USER PASSWORD=&PASSWORD DATABASE=&DATABASE SCHEMA=&SCHEMA;
      %let GRIDDATASERVER = &GRIDHOST;
      %let HDFS_PATH=;
   %end;
   %else %if %upcase(&engine)=SASHDAT %then %do;
      %let SERVER=HOST="&GRIDHOST" INSTALL="&GRIDINSTALLLOC";
      %let GRIDDATASERVER = &GRIDHOST;
      %let HDFS_PATH      = HDFS_PATH="&HDFS_PATH";
   %end;

%mend;

%appliance;

 /*------------------------------------------------------------*/
 /*- Creating libname statement for running alongside the DB  -*/
 /*------------------------------------------------------------*/

libname GridLib &engine
         &SERVER
         &HDFS_PATH;

%let LIBTYPE = &ENGINE;

 /*------------------------------------------------------------*/
 /*- HPATEST run to check grid and assign macro variable      -*/
 /*- HPA_ENABLED which is used for NODES= value in the        -*/
 /*- PERFORMANCE statement of the procedure runs.             -*/
 /*------------------------------------------------------------*/

proc hpatest;
   performance nodes=ALL
               HOST="&GRIDHOST"
               INSTALLLOC="&GRIDINSTALLLOC";
run;

%let PERFORMANCE_OPTS=NODES=&HPA_ENABLED host="&GRIDHOST"
 installloc="&GRIDINSTALLLOC";
