/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPCNT                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPCOUNTREG               */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPCOUNTREG, DATA STEP                               */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/

%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;

%macro poisson(n_obs, n_x, n_indep, n_zero);
data simulate_tsthpcnt;
    call streaminit(12345);
    array vars x1-x&n_x;
    array parm p1-p&n_indep;
    array zero_parm z1-z&n_zero;
    x_std=.2;
    x_mean=.3;
    intercept=2;
    parm_std=.3;
    parm_mean=0;
    z_parm_std=.3;
    z_parm_mean=0.5;
    z_intercept=-1;

    do j=1 to &n_indep;
        parm[j]=rand('NORMAL',parm_mean,parm_std);
        end;
    do j=1 to &n_zero;
        zero_parm[j]=rand('NORMAL',z_parm_mean,z_parm_std);
        end;
    do i=1 to &n_obs;
        do j=1 to &n_x;
            vars[j]=rand('NORMAL',x_mean,x_std);
            end;
        off1=rand('NORMAL');
        off2=rand('NORMAL');
        x_beta=0;
        do j=1 to &n_indep;
            x_beta=x_beta+parm[j]*vars[j];
            end;
        x_beta=intercept+x_beta+off1;
        u=exp(x_beta+0.2*rand('NORMAL'));
        y=rand('POISSON',u);
        zr=zero_parm[1]*vars[1]+zero_parm[2]*vars[6]+
           zero_parm[3]*vars[11]+zero_parm[4]*vars[12]+
           zero_parm[5]*vars[15]+z_intercept;
        zr=zr+off2;
        pzero = cdf('LOGISTIC',zr);
        if rand('UNIFORM')<pzero then y=0;
        output;
        end;
    keep y x1-x&n_x off1 off2;
run;

%mend;

%poisson(n_obs=10000, n_x=15, n_indep=10, n_zero=5);

run;

 *- SMP MODE -*;
proc hpcountreg data=simulate_tsthpcnt type=poisson
                outest=outest_SMP covout;
    ods output FitSummary = fitsum_SMP
               ParameterEstimates = est_SMP;
    model y=x1-x10;
    output out=out_SMP xbeta=xbeta prob=prob exp=exp
           probcounts(0 3 2 1)=(p);
run;

%macro checkforsashdat(ds);
 %global GRIDLIB;
 %if %index(&ENGINE,SASHDAT) %then %do;
  %let GRIDLIB=GRIDLIB;
  data GRIDLIB.&ds (blocksize=1M
                    copies   =0
                    replace  =yes);
   set &ds;
  run;
 %end;
 %else %do;
  %let GRIDLIB=WORK;
 %end;
%mend;

%checkforsashdat(simulate_tsthpcnt);

 *- MPP MODE -*;
proc hpcountreg data=&GRIDLIB..simulate_tsthpcnt type=poisson
                outest=outest_MPP covout;
    ods output FitSummary = fitsum_MPP
               ParameterEstimates = est_MPP;
    model y=x1-x10;
    performance &PERFORMANCE_OPTS;
    output out=out_MPP xbeta=xbeta prob=prob exp=exp
           probcounts(0 3 2 1)=(p);
run;

proc delete data=&GRIDLIB..simulate_tsthpcnt;
run;

/* expected output for fit sum */
data fitsum2;
    input nValue1;
datalines;
 .
10000.0000
 .
 .
-129676.18
0.00000000
6.00000000
 .
259374.370
259453.684
;

data fitsum1_SMP;
    set fitsum_SMP(keep=nValue1);
run;

data fitsum1_MPP;
    set fitsum_MPP(keep=nValue1);
run;

%check(fitsum1_SMP,fitsum2,
       %str(method=relative(0.01) criterion=.0001),);
%check(fitsum1_MPP,fitsum2,
       %str(method=relative(0.01) criterion=.0001),);


/* expected output for estimate */
data est2;
    input DF Estimate StdErr tValue Probt;
datalines;
1  2.28374745  0.01470722  155.280658  0.00000000
1  -.18222335  0.01527489  -11.929598  0.00000000
1  0.28878272  0.01512143  19.0975736  0.00000000
1  0.23270917  0.01517037  15.3397173  0.00000000
1  -.17301810  0.01506875  -11.481915  0.00000000
1  0.37261317  0.01512211  24.6402945  0.00000000
1  -.62517773  0.01525553  -40.980392  0.00000000
1  -.12234110  0.01519442  -8.0517115  0.00000000
1  0.05974004  0.01523899  3.92020954  0.00008847
1  0.16294460  0.01521345  10.7105640  0.00000000
1  0.24841119  0.01519388  16.3494230  0.00000000
;

data est1_SMP;
    set est_SMP(keep=DF Estimate StdErr tValue Probt);
run;

data est1_MPP;
    set est_MPP(keep=DF Estimate StdErr tValue Probt);
run;

%check(est1_SMP,est2,%str(method=absolute criterion=.0001),);
%check(est1_MPP,est2,%str(method=absolute criterion=.0001),);


data outest2a;
    input Intercept x1 x2 x3 x4;
datalines;
2.28374745    -.18222335  0.28878272    0.23270917    -.17301810
0.01470722    0.01527489  0.01512143    0.01517037    0.01506875
0.00021630    -.00006695  -.00006824    -.00007232    -.00006300
-.00006695    0.00023332  -.00000201    0.00000079    0.00000141
-.00006824    -.00000201  0.00022866    -.00000171    -.00000162
-.00007232    0.00000079  -.00000171    0.00023014    -.00000006
-.00006300    0.00000141  -.00000162    -.00000006    0.00022707
-.00006983    -.00000229  0.00000065    -.00000148    -.00000345
-.00006256    -.00000137  -.00000368    -.00000014    0.00000061
-.00007200    0.00000251  0.00000132    0.00000383    -.00000125
-.00006952    -.00000024  0.00000112    0.00000011    -.00000318
-.00007492    0.00000078  0.00000120    0.00000029    0.00000026
-.00006823    -.00000180  -.00000205    -.00000010    -.00000171
;

data outest2b;
    input x5 x6 x7 x8;
datalines;
0.37261317    -.62517773   -.12234110    0.05974004
0.01512211    0.01525553   0.01519442    0.01523899
-.00006983    -.00006256   -.00007200    -.00006952
-.00000229    -.00000137   0.00000251    -.00000024
0.00000065    -.00000368   0.00000132    0.00000112
-.00000148    -.00000014   0.00000383    0.00000011
-.00000345    0.00000061   -.00000125    -.00000318
0.00022868    0.00000039   -.00000129    0.00000056
0.00000039    0.00023273   0.00000350    -.00000066
-.00000129    0.00000350   0.00023087    -.00000248
0.00000056    -.00000066   -.00000248    0.00023223
0.00000178    0.00000093   0.00000566    0.00000298
-.00000300    -.00000210   -.00000085    -.00000123
;

data outest2c;
    input x9 x10;
datalines;
0.16294460    0.24841119
0.01521345    0.01519388
-.00007492    -.00006823
0.00000078    -.00000180
0.00000120    -.00000205
0.00000029    -.00000010
0.00000026    -.00000171
0.00000178    -.00000300
0.00000093    -.00000210
0.00000566    -.00000085
0.00000298    -.00000123
0.00023145    -.00000030
-.00000030    0.00023085
;

data outest2;
    merge outest2a outest2b outest2c;
run;

data outest1_SMP;
    set outest_SMP(drop=_NAME_ _TYPE_ _STATUS_);
run;

data outest1_MPP;
    set outest_MPP(drop=_NAME_ _TYPE_ _STATUS_);
run;

%check(outest1_SMP,outest2,%str(method=absolute criterion=.0001),);
%check(outest1_MPP,outest2,%str(method=absolute criterion=.0001),);


data out2a;
    input xbeta exp prob p_0;
datalines;
2.15999421    8.67108742    0.00000010    0.00017147
2.62078416    13.7464988    0.00000107    0.00000107
2.44515961    11.5323901    0.11789719    0.00000981
2.71114623    15.0465124    0.00000029    0.00000029
2.65048516    14.1609073    0.00000000    0.00000071
2.42572876    11.3104690    0.04197551    0.00001224
2.46930150    11.8141918    0.00000740    0.00000740
2.37527484    10.7539684    0.08825196    0.00002136
2.22646960    9.26709168    0.00009448    0.00009448
2.24152725    9.40768823    0.01139175    0.00008209
;

data out2b;
    input p_3 p_2 p_1;
datalines;
0.01863220    0.00644632    0.00148685
0.00046387    0.00010123    0.00001473
0.00250699    0.00065216    0.00011310
0.00016578    0.00003305    0.00000439
0.00033506    0.00007098    0.00001003
0.00295268    0.00078317    0.00013849
0.00203340    0.00051634    0.00008741
0.00442757    0.00123515    0.00022971
0.01253235    0.00405705    0.00087558
0.01139175    0.00363269    0.00077228
;

data out2;
    merge out2a out2b;
run;

data out1_SMP;
    set out_SMP(obs=10);
run;

data out1_MPP;
    set out_MPP(obs=10);
run;

%check(out1_SMP,out2,%str(method=absolute criterion=.0001),);
%check(out1_MPP,out2,%str(method=absolute criterion=.0001),);
