/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPCORR                                           */
/*   TITLE: INSTALLATION TEST FOR PROC HPCORR                   */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPCORR, DATA STEP                                   */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/


%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;

data a_tsthpcor;
input i x y z w wgt freq abc @@;
cards;
  1  1  1  1  1 0.8  3   1  2  2  5  4  1 0.5  2   4
  3  4  6 13  2 0.6  2  13  4  5  9 10  2 0.5  2  10
  5  6 13  8  2 0.5  2   8  6  6  7  9  1 0.4  2   9
  7  9 10 13  2 0.3  2  13  8  9  9 12  2 0.3  1  12
  9 12 10  9  4 0.2  1   9 10 11 11 15  2 0.4  2  15
11 14 11 20  4 0.8  3  20 12 14 14 24  3 0.2  1  24
13 14 13 17  2 0.7  3  17 14 16 16 18  3 0.7  3  18
15 16 19 19  2 0.8  3  19 16 17 19 16  2 0.7  3  19
17 18 19 17  2 0.2  1  19 18 19 21 20  2 0.8  3  21
19 21 19 19  3 0.4  2  19 20 23 23 32  3 0.6  2  23
21 22 21 21  2 0.5  2  21 22 24 24 25  3 0.2  1  24
23 23 32 25  1 0.7  2  32 24 25 29 27  2 0.6  2  29
25 25 29 28  1 0.7  1  29 26 27 26 28  2 0.8  3  26
27 28 30 31  2 0.6  2  30 28 28 31 29  1 0.1  1  31
29 29 37 33  1 0.5  2  37 30 32 36 30  3 0.5  2  36
;
run;



 *- SMP MODE -*;
proc hpcorr data=a_tsthpcor;
    ods output  SimpleStats=SimpleStats_SMP
                PearsonCorr=PearsonCorr_SMP;
   var x y z;
   freq freq;
   weight wgt;
run;

%macro checkforsashdat(ds);
 %global GRIDLIB;
 %if %index(&ENGINE,SASHDAT) %then %do;
  %let GRIDLIB=GRIDLIB;
  data GRIDLIB.&ds (blocksize=1M
                    copies   =0
                    replace  =yes);
   set &ds;
  run;
 %end;
 %else %do;
  %let GRIDLIB=WORK;
 %end;
%mend;

%checkforsashdat(a_tsthpcor);


 *- MPP MODE -*;
proc hpcorr data=&GRIDLIB..a_tsthpcor;
    ods output  SimpleStats=SimpleStats_MPP
                PearsonCorr=PearsonCorr_MPP;
   var x y z;
   freq freq;
   weight wgt;
   performance &PERFORMANCE_OPTS;
run;

proc delete data=&GRIDLIB..a_tsthpcor;
run;

/* expected output for SimpleStats */
data SimpleStats2(label='Simple Statistics');
    length variable $ 8;
    input variable nobs mean stddev sum min max;
datalines;
x   61   16.38701    6.54191  580.10000    1.00000   32.00000
y   61   17.92373    7.23452  634.50000    1.00000   37.00000
z   61   18.81921    6.49082  666.20000    1.00000   33.00000
;

%check(SimpleStats_SMP,SimpleStats2,
  %str(method=absolute criterion=.0001),%str(drop=variable));
%check(SimpleStats_MPP,SimpleStats2,
  %str(method=absolute criterion=.0001),%str(drop=variable));


/* expected output for PearsonCorr */
data PearsonCorr2(label='Pearson Correlations');
    length variable $ 1;
    format Px Py Px pvalue8.4;
    input variable x y z Px Py Pz;
datalines;
x   1.00000   0.95277   0.94773     ._       0.0000    0.0000
y   0.95277   1.00000   0.90031    0.0000    ._        0.0000
z   0.94773   0.90031   1.00000    0.0000    0.0000    ._
;

%check(PearsonCorr_SMP,PearsonCorr2,
  %str(method=absolute criterion=.0001),%str(drop=variable));
%check(PearsonCorr_MPP,PearsonCorr2,
  %str(method=absolute criterion=.0001),%str(drop=variable));
