/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPLMX                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPLMIXED                 */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPLMIXED, DATA STEP                                 */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/

%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='')
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend check;

data one_tsthplmx;
    input a b y;
datalines;
1 1 8
1 1 9
2 1 7
1 2 15
1 2 12
2 2 6
2 2 7
2 1 9
;

 *- SMP MODE -*;
proc hplmixed data=one_tsthplmx;
    class a b;
    model y=/s;
    random a/s;
    random int/sub=b;
    ods output
        ModelInfo         = ModelInfoHpl_SMP
        ClassLevels       = ClassLevelsHpl_SMP
        Dimensions        = DimensionsHpl_SMP
        NObs              = NObsHpl_SMP
        ConvergenceStatus = ConvergenceStatusHpl_SMP
        CovParms          = CovParmsHpl_SMP
        FitStatistics     = FitStatisticsHpl_SMP
        SolutionF         = SolutionFHpl_SMP
        SolutionR         = SolutionRHpl_SMP
        ;
run;

%macro checkforsashdat(ds);
 %global GRIDLIB;
 %if %index(&ENGINE,SASHDAT) %then %do;
  %let GRIDLIB=GRIDLIB;
  data GRIDLIB.&ds (blocksize=1M
                    copies   =0
                    replace  =yes);
   set &ds;
  run;
 %end;
 %else %do;
  %let GRIDLIB=WORK;
 %end;
%mend;

%checkforsashdat(one_tsthplmx);

 *- MPP MODE -*;
proc hplmixed data=&GRIDLIB..one_tsthplmx;
    class a b;
    model y=/s;
    random a/s;
    random int/sub=b;
    ods output
        ModelInfo         = ModelInfoHpl_MPP
        ClassLevels       = ClassLevelsHpl_MPP
        Dimensions        = DimensionsHpl_MPP
        NObs              = NObsHpl_MPP
        ConvergenceStatus = ConvergenceStatusHpl_MPP
        CovParms          = CovParmsHpl_MPP
        FitStatistics     = FitStatisticsHpl_MPP
        SolutionF         = SolutionFHpl_MPP
        SolutionR         = SolutionRHpl_MPP
        ;
    performance &PERFORMANCE_OPTS;
run;

proc delete data=&GRIDLIB..one_tsthplmx;
run;

/* expected output */
data ClassLevels2(label='ClassLevels2');
    input Levels;
datalines;
2
2
;

%check(ClassLevelsHpl_SMP,ClassLevels2,
  %str(method=absolute criterion=.0001),%str(drop=Class Values));
%check(ClassLevelsHpl_MPP,ClassLevels2,
  %str(method=absolute criterion=.0001),%str(drop=Class Values));

/* expected output */
data Dimensions2(label='Dimensions');
    input Value;
datalines;
3
1
4
1
8
;

%check(DimensionsHpl_SMP,Dimensions2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));
%check(DimensionsHpl_MPP,Dimensions2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));

/* expected output */
data NObs2(label='NObs');
    input N NobsRead   NobsUsed  SumFreqsRead  SumFreqsUsed;
datalines;
8    8     8     8      8
8    8     8     8      8
0    8     8     8      8
;

%check(NObsHpl_SMP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=Label));
%check(NObsHpl_MPP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=Label));

/* expected output */
data ConvergenceStatus2(label='ConvergenceStatus');
    input Status pdG;
datalines;
0 1
;

%check(ConvergenceStatusHpl_SMP,ConvergenceStatus2,
  %str(method=absolute criterion=.0001),%str(drop=Reason));
%check(ConvergenceStatusHpl_MPP,ConvergenceStatus2,
  %str(method=absolute criterion=.0001),%str(drop=Reason));


/* expected output */
data CovParms2(label='CovParms');
    input Estimate;
datalines;
5.6000
0.1000
5.7250
;

%check(CovParmsHpl_SMP,CovParms2,
  %str(method=absolute criterion=.0001),%str(drop=CovParm Subject));
%check(CovParmsHpl_MPP,CovParms2,
  %str(method=absolute criterion=.0001),%str(drop=CovParm Subject));

/* expected output */
data FitStatistics2(label='FitStatistics');
    input Value;
datalines;
35.8178
41.8178
49.8178
37.8973
;

%check(FitStatisticsHpl_SMP,FitStatistics2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));
%check(FitStatisticsHpl_MPP,FitStatistics2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));

/* expected output */
data SolutionF2(label='SolutionF');
    input Estimate StdErr DF tValue Probt;
datalines;
9.1250      1.8883       7       4.83    0.0019
;

%check(SolutionFHpl_SMP,SolutionF2,
  %str(method=absolute criterion=.01),%str(drop=Effect));
%check(SolutionFHpl_MPP,SolutionF2,
  %str(method=absolute criterion=.01),%str(drop=Effect));

/* expected output */
data SolutionR2(label='SolutionR');
    missing _;
    input a b Estimate StdErrPred DF tValue Probt;
datalines;
1   _     1.4933     1.8357      7      0.81   0.4427
2   _    -1.4933     1.8357      7     -0.81   0.4427
_   1   -0.05714     0.3110      7     -0.18   0.8594
_   2    0.05714     0.3110      7      0.18   0.8594
;

%check(SolutionRHpl_SMP,SolutionR2,
  %str(method=absolute criterion=.01),%str(drop=Effect));
%check(SolutionRHpl_MPP,SolutionR2,
  %str(method=absolute criterion=.01),%str(drop=Effect));
