/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPLOG                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPLOGISTIC               */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPLOGISTIC, DATA STEP                               */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/


%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;


data neuralgia_tsthplog;
   length Pain $ 2;
   input Treatment $ Sex $ Age Duration Pain $ @@;
datalines;
A  M  71  17   P     A  F  63  27  PF    A  F  69  18   P
P  F  68   1  PF     B  M  74  16  PF    P  F  67  30  PF
P  M  66  26   P     B  F  67  28  PF    B  F  77  16  PF
A  F  71  12  PF     B  F  72  50  PF    B  F  76   9   P
B  F  66  12  PF     A  M  62  42  PF    P  F  64   1   P
A  F  64  17  PF     P  M  74   4  PF    A  F  72  25  PF
P  M  70   1   P     B  M  66  19  PF    B  M  59  29  PF
A  F  64  30  PF     A  M  70  28  PF    A  M  69   1  PF
B  F  78   1  PF     P  M  83   1   P    B  F  69  42  PF
B  M  75  30   P     P  M  77  29   P    P  F  79  20   P
A  M  70  12  PF     A  F  69  12  PF    B  F  65  14  PF
B  M  70   1  PF     B  M  67  23  PF    A  M  76  25   P
P  M  78  12   P     B  M  77   1   P    B  F  69  24  PF
P  M  66   4   P     P  F  65  29  PF    P  M  60  26   P
A  M  78  15   P     B  M  75  21   P    A  F  67  11  PF
P  F  72  27  PF     P  F  70  13   P    A  M  75   6   P
B  F  65   7  PF     P  F  68  27   P    P  M  68  11   P
P  M  67  17   P     B  M  70  22  PF    A  M  65  15  PF
P  F  67   1   P     A  M  67  10  PF    P  F  72  11   P
A  F  74   1  PF     B  M  80  21   P    A  F  69   3  PF
;

 *- SMP MODE -*;
proc hplogistic data=neuralgia_tsthplog;
    ods output NObs=NObs_SMP
        ClassLevels=ClassLevels_SMP
        ResponseProfile=ResponseProfile_SMP
        Dimensions=Dimensions_SMP
        FitStatistics=FitStatistics_SMP
        GlobalTests=GlobalTests_SMP
        ParameterEstimates=ParameterEstimates_SMP;
    class treatment sex;
    model pain = duration sex treatment;
run;

%macro checkforsashdat(ds);
 %global GRIDLIB;
 %if %index(&ENGINE,SASHDAT) %then %do;
  %let GRIDLIB=GRIDLIB;
  data GRIDLIB.&ds (blocksize=1M
                    copies   =0
                    replace  =yes);
   set &ds;
  run;
 %end;
 %else %do;
  %let GRIDLIB=WORK;
 %end;
%mend;

%checkforsashdat(neuralgia_tsthplog);

 *- MPP MODE -*;
proc hplogistic data=&GRIDLIB..neuralgia_tsthplog;
    ods output NObs=NObs_MPP
        ClassLevels=ClassLevels_MPP
        ResponseProfile=ResponseProfile_MPP
        Dimensions=Dimensions_MPP
        FitStatistics=FitStatistics_MPP
        GlobalTests=GlobalTests_MPP
        ParameterEstimates=ParameterEstimates_MPP;
    class treatment sex;
    model pain = duration sex treatment;
    performance &PERFORMANCE_OPTS;
run;

proc delete data=&GRIDLIB..neuralgia_tsthplog;
run;

data NObs2(label='Number of Observations');
    length label $ 27;
    input label $ 1-27 N NObsRead NObsUsed SumFreqsRead SumFreqsUsed;
datalines;
Number of Observations Read    60  60  60  60 60
Number of Observations Used    60  60  60  60 60
;

%check(NObs_SMP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=label));
%check(NObs_MPP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=label));


data ClassLevels2(label='Class Level Information');
    length class $ 9 values $ 6;
    input Class $ Levels Values $ 24-28;
datalines;
treatment         3    A B P
sex               2    F M
;

%check(ClassLevels_SMP,Classlevels2,
  %str(method=absolute criterion=.0001),%str(drop=class));
%check(ClassLevels_MPP,Classlevels2,
  %str(method=absolute criterion=.0001),%str(drop=class));


data Dimensions2(label='Dimensions');
    length Descr $ 28;
    input Descr $ 1-28 Value;
datalines;
Columns in X                         7
Number of Effects                    4
Max Effect Columns                   3
Rank of Cross-product Matrix         5
Parameters in Optimization           5
;

%check(Dimensions_SMP,Dimensions2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));
%check(Dimensions_MPP,Dimensions2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));


data FitStatistics2(label='Fit Statistics');
    length Descr $ 24;
    input Descr $ 1-24 Value;
datalines;
-2 Log Likelihood            59.2126056
AIC (smaller is better)      69.2126056
AICC (smaller is better)     70.3237167
BIC (smaller is better)      79.6843284
;

%check(FitStatistics_SMP,FitStatistics2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));
%check(FitStatistics_MPP,FitStatistics2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));


data ParameterEstimates2(label='Parameter Estimates');
    length effect $ 9 parameter $ 11 sex treatment $ 1;
    input Effect $ Parameter $ 12-22 Sex $ 26 Treatment $ 29
          Estimate Stderr DF tValue Probt;
datalines;
Intercept  Intercept             2.57281 0.91403  .I  2.81479 0.00488
Duration   Duration             -0.02401 0.02972  .I -0.80776 0.41923
Sex        Sex F         F      -1.78889 0.71734  .I -2.49379 0.01264
Sex        Sex M         M       0.00000  .       .   .       .
Treatment  Treatment A      A   -2.59003 0.84809  .I -3.05395 0.00226
Treatment  Treatment B      B   -2.54305 0.85115  .I -2.98778 0.00281
Treatment  Treatment P      P    0.00000  .       .   .       .
;

%check(ParameterEstimates_SMP,ParameterEstimates2,
  %str(method=absolute criterion=.0001),
  %str(drop=Effect treatment sex parameter));
%check(ParameterEstimates_MPP,ParameterEstimates2,
  %str(method=absolute criterion=.0001),
  %str(drop=Effect treatment sex parameter));
