 /****************************************************************/
 /*          S A S   I N S T A L L A T I O N   T E S T           */
 /*                                                              */
 /*    NAME: TSTHPNEU                                            */
 /*   TITLE: INSTALLATION TEST FOR PROC HPNEURAL                 */
 /* PRODUCT: HPA                                                 */
 /*  SYSTEM:                                                     */
 /*    KEYS:                                                     */
 /*   PROCS: HPNEURAL, DATA STEP                                 */
 /*    DATA:                                                     */
 /*                                                              */
 /* SUPPORT:                                                     */
 /*  UPDATE:                                                     */
 /*     REF:                                                     */
 /*    MISC:                                                     */
 /*                                                              */
 /****************************************************************/


%macro check(data1,data2,opts,drop);

 proc compare base=&data1(label='' &drop)
              compare=&data2(label='' &drop)
              outstats=check nosummary &opts;
   attrib _all_ format = label = '';
 run;

 %rccheck(&sysinfo,0);

%mend;


data matrix_tsthpneu;
input x1-x3;
cards;
  1  1  1
  1  1  1
  0  0  0
  0  0  0
run;

 *- SMP MODE -*;
proc hpneural data=matrix_tsthpneu;
 ods output Nobs=Nobs_SMP
            MisClassification=MisClassification_SMP
            Training=Training_SMP
            Iteration=Iteration_SMP;
    input  x1-x2;
    hidden 2;
    target x3 /level=nom;
    train numtries=5 valid=_none_;
    score out=xoscores_SMP;
run;

%macro checkforsashdat(ds);
 %global GRIDLIB;
 %if %index(&ENGINE,SASHDAT) %then %do;
  %let GRIDLIB=GRIDLIB;
  data GRIDLIB.&ds (blocksize=1M
                    copies   =0
                    replace  =yes);
   set &ds;
  run;
 %end;
 %else %do;
  %let GRIDLIB=WORK;
 %end;
%mend;

%checkforsashdat(matrix_tsthpneu);

 *- MPP MODE -*;
proc hpneural data=&GRIDLIB..matrix_tsthpneu;
 ods output Nobs=Nobs_MPP
            MisClassification=MisClassification_MPP
            Training=Training_MPP
            Iteration=Iteration_MPP;
    input  x1-x2;
    hidden 2;
    target x3/level=nom;
    train numtries=5 valid=_none_;
    score out=xoscores_MPP;
    &performance_statement;
run;

proc delete data=&GRIDLIB..matrix_tsthpneu;
run;

data NObs(label='Number of Observations');
 length label $ 27;
 input label $ 1-27 N NObsRead NObsUsed SumFreqsRead SumFreqsUsed;
cards;
Number of Observations Read   4  4  4  4  4
Number of Observations Used   4  4  4  4  4
Number Used for Training      4  0  0  0  0
Number Used for Validation    0  0  0  0  0
;
run;
%check(NObs_SMP,NObs,
  %str(method=absolute criterion=.0001),%str(drop=label));
%check(NObs_MPP,NObs,
  %str(method=absolute criterion=.0001),%str(drop=label));

data MisClassification(label='Misclassification Table for x3');
 format _0 _1 8.;
 input VarName $ Class $6 _0 _1;
cards;
 x3  0   2  0
 x3  1   0  2
;
run;
%check(MisClassification_SMP,MisClassification,
  %str(method=absolute criterion=.0001),%str(drop=VarName Class));
%check(MisClassification_MPP,MisClassification,
  %str(method=absolute criterion=.0001),%str(drop=VarName Class));


data Training(label='Training Table');
 input TryNum NumIterations TrainingError
       ValidationError StoppingReason $22-35
       Best $39;
cards;
1  14 0.000020341 .  Training Error
2  14 0.000018209 .  Training Error
3  13 0.000022296 .  Training Error
4   9 0.000018977 .  Training Error
5  11 0.000012944 .  Training Error   Y
;
run;
%check(Training_SMP,Training,
  %str(method=absolute criterion=.0001),%str(drop=StoppingReason Best));
%check(Training_MPP,Training,
  %str(method=absolute criterion=.0001),%str(drop=StoppingReason Best));


data Iteration(label='Iteration Table');;
 input IterationNum TrainingError ValidationError Best $24;
cards;
  0      0.487210    .
  1      0.011575    .
  2      0.006915    .
  3      0.003289    .
  4      0.001679    .
  5      0.000831    .
  6      0.000417    .
  7      0.000208    .
  8      0.000104    .
  9   0.000051860    .
 10   0.000025909    .
 11   0.000012944    . Y
;
run;
%check(Iteration_SMP,Iteration,
  %str(method=absolute criterion=.0001),%str(drop=best));
%check(Iteration_MPP,Iteration,
  %str(method=absolute criterion=.0001),%str(drop=best));


data xoscores;
 input x3 $ I_V1 $ P_V1L0 P_V1L1 _WARN_ $36;
cards;
 1      1      0.00001    0.99999
 1      1      0.00001    0.99999
 0      0      0.99999    0.00001
 0      0      0.99999    0.00001
;
run;
%check(xoscores_SMP,xoscores,
       %str(method=absolute criterion=0.0001),%str(drop=x3 _WARN_ I_V1));
%check(xoscores_MPP,xoscores,
       %str(method=absolute criterion=0.0001),%str(drop=x3 _WARN_ I_V1));
