/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPNLN                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPREG                    */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPNLIN, DATA STEP                                   */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/


%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;

data crowder_tsthpnln;
    input treat rate seed extract y;
datalines;
 1       0.0      1       1.0       1.45
 0       0.6      2       1.3      -2.69
 1       2.7      0       1.8       4.80
 1       0.0      1       0.8      -1.57
 1       0.4      2       2.2       0.91
 1       0.6      0       0.8      -0.96
 1       0.2      1       1.5       0.42
 1       0.3      2       1.2      -0.81
 0       0.1      0       1.4      -1.15
 1       0.4      1       0.5      -0.89
 1       0.1      2       0.8      -1.32
 1       3.0      0       0.5       0.21
 1       0.8      1       0.6      -1.88
 1       0.8      2       0.6      -1.62
 1       0.3      0       1.1      -0.99
 1       3.8      1       1.6       2.97
 0       0.8      2       2.1       0.28
 1       1.3      0       1.4       3.16
 1       2.6      1       0.9       1.29
 1       0.6      2       0.7      -1.00
 1       0.6      0       0.3      -1.20
 1       0.3      1       2.0       1.59
 1       1.7      2       0.9       0.15
 1       1.3      0       1.5       3.45
 1       3.3      1       0.7       1.14
 0       0.1      2       0.7      -5.20
 1       0.9      0       0.9       0.43
 0       0.6      1       1.7      -0.30
 1       0.4      2       1.3      -0.48
 0       1.9      0       0.3      -3.89
 0       0.4      1       0.3      -5.78
 1       0.7      2       1.6       1.19
 1       1.5      0       1.6       2.21
 1       3.1      1       1.5       2.23
 0       2.4      2       1.4      -1.63
 1       0.5      0       0.6      -2.38
 1       0.5      1       1.0      -0.62
 0       3.1      2       0.6      -2.94
 1       1.9      0       0.6      -0.01
 1       0.5      1       2.0       0.94
 1       0.1      2       1.1      -0.47
 1       2.1      0       1.7       2.66
 1       0.2      1       0.4      -3.56
 0       0.1      2       0.8      -2.02
 1       1.9      0       1.4       1.88
 1       1.5      1       0.4      -1.39
 1       0.4      2       1.0      -0.07
 0       0.7      0       1.4      -0.57
 1       0.7      1       1.6       2.40
 1       0.9      2       2.1       0.60
;

 *- SMP MODE -*;
proc hpnlin data=crowder_tsthpnln noitprint;
    ods output Nobs=Nobs_SMP
               Dimensions=Dimensions_SMP
               Parameters=Parameters_SMP
               Fitstatistics=Fitstatistics_SMP
               Anova=Anova_SMP
               Parameterestimates=Parameterestimates_SMP;
    parms b0=1 b1=1 b2=1 b3=1 b4=1;
    model y~residual(b0+b1*treat+b2*rate+b3*seed+b4*log(extract));
run;

%macro checkforsashdat(ds);
 %global GRIDLIB;
 %if %index(&ENGINE,SASHDAT) %then %do;
  %let GRIDLIB=GRIDLIB;
  data GRIDLIB.&ds (blocksize=1M
                    copies   =0
                    replace  =yes);
   set &ds;
  run;
 %end;
 %else %do;
  %let GRIDLIB=WORK;
 %end;
%mend;

%checkforsashdat(crowder_tsthpnln);

 *- MPP MODE -*;
proc hpnlin data=&GRIDLIB..crowder_tsthpnln noitprint;
    ods output Nobs=Nobs_MPP
               Dimensions=Dimensions_MPP
               Parameters=Parameters_MPP
               Fitstatistics=Fitstatistics_MPP
               Anova=Anova_MPP
               Parameterestimates=Parameterestimates_MPP;
    parms b0=1 b1=1 b2=1 b3=1 b4=1;
    model y~residual(b0+b1*treat+b2*rate+b3*seed+b4*log(extract));
    performance &PERFORMANCE_OPTS;
run;

proc delete data=&GRIDLIB..crowder_tsthpnln;
run;

/* expected output for Simension */
data Dimensions2(label='Dimensions');
    input Descr$10. Value;
datalines;
Parameters       5
;

%check(Dimensions_SMP,Dimensions2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));
%check(Dimensions_MPP,Dimensions2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));

/* expected output for Parameters */
data Parameters2(Label='Parameters');
    input b0 b1 b2 b3 b4 Objective;
datalines;
1 1 1 1 1 19.8905481
;

%check(Parameters_SMP,Parameters2,
  %str(method=absolute criterion=.0001));
%check(Parameters_MPP,Parameters2,
  %str(method=absolute criterion=.0001));

/* expected output for Fit Statistics */
data Fitstatistics2(Label='Fit Statistics');
    input Descr $14. Value;
datalines;
SS(Error)         31.9182
Error Variance    0.7093
;

%check(Fitstatistics_SMP,Fitstatistics2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));
%check(Fitstatistics_MPP,Fitstatistics2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));

/* expected output for Analysis of Variance */
data Anova2(Label='Analysis of Variance');
    input Source $15. DF SS MS FValue ProbF;
datalines;
Model            4   194.4146    48.6037 68.5240  0.0001
Error            45  31.9182     0.7093     ._       ._
Corrected Total  49  226.3329     ._        ._       ._
;

%check(Anova_SMP,Anova2,
  %str(method=absolute criterion=.0001),%str(drop=Source));
%check(Anova_MPP,Anova2,
  %str(method=absolute criterion=.0001),%str(drop=Source));

/* expected output for Parameter Estimates */
data Parameterestimates2(Label='Parameter Estimates');
    input Parameter$2. Estimate Standarderror DF tValue Probt Alpha Lower Upper;
datalines;
b0      -2.0195   0.3586   45   -5.6320  0.0001   0.05  -2.7417  -1.2973
b1       2.2212   0.2928   45    7.5854  0.0001   0.05   1.6314   2.8110
b2       0.6544   0.1216   45    5.3832  0.0001   0.05   0.4095   0.8992
b3      -0.5891   0.1536   45   -3.8344  0.0004   0.05  -0.8986  -0.2797
b4       2.6146   0.2229   45   11.7278  0.0001   0.05   2.1656   3.0636
;

%check(Parameterestimates_SMP,Parameterestimates2,
  %str(method=absolute criterion=.0001),%str(drop=Parameter));
%check(Parameterestimates_MPP,Parameterestimates2,
  %str(method=absolute criterion=.0001),%str(drop=Parameter));
