/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPQLM                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPQLIM                   */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPQLIM, DATA STEP                                   */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/


%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;

data hqldata_tsthpqlm;
  do i=1 to 10000;
    z1=5*ranuni(12456);
    z2=3*ranuni(234562);
    x1=3*abs(rannor(120034));
    x2=ranexp(45600);
    y2=-10+2*x1+.1*x2+rannor(345);
    tmp=abs(rannor(45234));
    lower=y2-3*tmp;
    tmp=abs(ranexp(45234));
    upper=y2+3*tmp;
    output;
  end;
    keep z1 z2 x1 x2 y2 lower upper i;
run;

 *- SMP MODE -*;
proc hpqlim data=hqldata_tsthpqlm;
  ods output NObs=NObs_SMP
             SummaryContResponse=SummaryContResponse_SMP
             FitSummary=FitSummary_SMP
             ParameterEstimates=ParameterEstimates_SMP;
  model y2 = x1 x2;
  endogenous y2 ~ censored(lb=lower ub=upper);
run;

%macro checkforsashdat(ds);
 %global GRIDLIB;
 %if %index(&ENGINE,SASHDAT) %then %do;
  %let GRIDLIB=GRIDLIB;
  data GRIDLIB.&ds (blocksize=1M
                    copies   =0
                    replace  =yes);
   set &ds;
  run;
 %end;
 %else %do;
  %let GRIDLIB=WORK;
 %end;
%mend;

%checkforsashdat(hqldata_tsthpqlm);


 *- MPP MODE -*;
proc hpqlim data=&GRIDLIB..hqldata_tsthpqlm;
  ods output NObs=NObs_MPP
             SummaryContResponse=SummaryContResponse_MPP
             FitSummary=FitSummary_MPP
             ParameterEstimates=ParameterEstimates_MPP;
  model y2 = x1 x2;
  endogenous y2 ~ censored(lb=lower ub=upper);
  performance &PERFORMANCE_OPTS;
run;

proc delete data=&GRIDLIB..hqldata_tsthpqlm;
run;

/* expected output for NObs */
data NObs2(label='Number of Observations');
    length Descr $ 27;
    input Descr $ 1-27 N;
datalines;
Number of Observations Read   10000
Number of Observations Used   10000
;

%check(NObs_SMP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));
%check(NObs_MPP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=Descr));


/* expected output for Summary Statistics of Continuous Responses */
data SummaryContResponse2(label=
       'Summary Statistics of Continuous Responses');
    length type $ 16 variable $ 8;
    input variable $ mean stderr type $ lowerbound upperbound
          nlowerbound nupperbound;
datalines;
y2    -5.14648     3.736595 Censored   ._    ._     0      0
;

%check(SummaryContResponse_SMP,SummaryContResponse2,
  %str(method=absolute criterion=.0001),%str(drop=type variable));
%check(SummaryContResponse_MPP,SummaryContResponse2,
  %str(method=absolute criterion=.0001),%str(drop=type variable));


/* expected output for Fit Summary */
data FitSummary2(label='Fit Summary');
    length label1 $ 30 cvalue1 $ 12;
    input label1 $ 1-30 @35 cvalue1 $char12. nvalue1;
datalines;
Number of Endogenous Variables             1          1.000000
Endogenous Variable               y2                         .
Number of Observations                 10000             10000.0000000
Log Likelihood                        -14175            -14174.9002724
Maximum Absolute Gradient         1.83944E-9       1.839443E-9
Number of Iterations                       0                 0.0000000
Optimization Method               Quasi-Newton               .
AIC                                    28358             28357.8005448
Schwarz Criterion                      28387             28386.6419063
;

%check(FitSummary_SMP,FitSummary2,
  %str(method=absolute criterion=.0001),%str(drop=label1 cvalue1));
%check(FitSummary_MPP,FitSummary2,
  %str(method=absolute criterion=.0001),%str(drop=label1 cvalue1));


/* expected output for Parameter Estimates */
data ParameterEstimates2(label='Parameter Estimates');
    length parameter $ 9;
    input parameter $ estimate df stderr tvalue probt asterisk;
    format probt pvalue6.4;
datalines;
Intercept    -10.020585   1      0.019381  -517.0382   0.0000     0
x1             2.007822   1      0.005572  360.34845   0.0000     0
x2             0.113336   1      0.010247   11.06054   0.0000     0
_Sigma         0.998553   1      0.007061  141.41921   0.0000     0
;

%check(ParameterEstimates_SMP,ParameterEstimates2,
  %str(method=absolute criterion=.0001),%str(drop=parameter));
%check(ParameterEstimates_MPP,ParameterEstimates2,
  %str(method=absolute criterion=.0001),%str(drop=parameter));
