/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPSEV                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPSEVERITY               */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPSEVERITY, DATA STEP                               */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/

%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;


data test_sev1_tsthpsev(keep=y label='Simple Lognormal Sample');
    call streaminit(45678);
    label y='Response Variable';
    Mu = 1.5;
    Sigma = 0.25;
    do n = 1 to 500;
        y = exp(Mu) * rand('LOGNORMAL')**Sigma;
        output;
    end;
run;

 *- SMP MODE -*;
proc hpseverity data=test_sev1_tsthpsev print=all outest=outest_SMP
                outstat=outstat_SMP;
    ods output DescStats = DescStats_SMP
               ModelSelection = ModelSelection_SMP
               AllFitStatistics = AllFitStatistics_SMP
               OptimizationSummary = OptimizationSummary_SMP
               StatisticsOfFit = StatisticsOfFit_SMP
               ParameterEstimates = ParameterEstimates_SMP;
    loss y;
    dist logn;
    nloptions tech=quanew maxiter=25;
run;

%macro checkforsashdat(ds);
 %global GRIDLIB;
 %if %index(&ENGINE,SASHDAT) %then %do;
  %let GRIDLIB=GRIDLIB;
  data GRIDLIB.&ds (blocksize=1M
                    copies   =0
                    replace  =yes);
   set &ds;
  run;
 %end;
 %else %do;
  %let GRIDLIB=WORK;
 %end;
%mend;

%checkforsashdat(test_sev1_tsthpsev);

 *- MPP MODE -*;
proc hpseverity data=&GRIDLIB..test_sev1_tsthpsev print=all
            outest=outest_MPP outstat=outstat_MPP;
    ods output DescStats = DescStats_MPP
               ModelSelection = ModelSelection_MPP
               AllFitStatistics = AllFitStatistics_MPP
               OptimizationSummary = OptimizationSummary_MPP
               StatisticsOfFit = StatisticsOfFit_MPP
               ParameterEstimates = ParameterEstimates_MPP;
    loss y;
    dist logn;
    nloptions tech=quanew maxiter=25;
    performance &PERFORMANCE_OPTS;
run;

proc delete data=&GRIDLIB..test_sev1_tsthpsev;
run;

/* expected output */
data DescStats2(label='DescStats');
    input nValue1;
datalines;
500.000000
500.000000
1.77759056
8.68451379
4.49539803
1.15290359
;

%check(DescStats_SMP,DescStats2,
       %str(method=absolute criterion=.0001),%str(keep=nValue1));
%check(DescStats_MPP,DescStats2,
       %str(method=absolute criterion=.0001),%str(keep=nValue1));


/* expected output */
data ModelSelection2;
   Statistic=1521.32447;
run;

%check(ModelSelection_SMP,ModelSelection2,
       %str(method=absolute criterion=.0001),%str(keep=Statistic));
%check(ModelSelection_MPP,ModelSelection2,
       %str(method=absolute criterion=.0001),%str(keep=Statistic));


/* expected output */
data AllFitStatistics2;
    input Neg2LogLike AIC  AICC BIC KS AD CvM;
    _MODEL_='Logn';
datalines;
1521.32447  1525.32447 1525.34862 1533.75369 0.67254 0.31402 0.06041
;

%check(AllFitStatistics_SMP,AllFitStatistics2,
       %str(method=absolute criterion=.01),%str(drop=_MODEL_));
%check(AllFitStatistics_MPP,AllFitStatistics2,
       %str(method=absolute criterion=.01),
       %str(drop=_MODEL_ KS AD CvM));


/* expected output */
data StatisticsOfFit2;
    input nValue1;
datalines;
1521.32447
1525.32447
1525.34862
1533.75369
0.672536
0.314022
0.060413
;


%check(StatisticsOfFit_SMP,StatisticsOfFit2,
       %str(method=relative(0.01) criterion=.0001),%str(keep=nValue1));
data StatisticsOfFit_MPP; set StatisticsOfFit_MPP;
 if label1 in('Kolmogorov-Smirnov Statistic',
              'Anderson-Darling Statistic'
              'Cramer-von Mises Statistic') then delete;
run;
data StatisticsOfFit2; set StatisticsOfFit2;
 if _n_ > 4 then delete;
run;
%check(StatisticsOfFit_MPP,StatisticsOfFit2,
       %str(method=relative(0.01) criterion=.0001),%str(keep=nValue1));


/* expected output */
data ParameterEstimates2;
    input Estimate StdErr tValue Probt;
datalines;
1.47086185  0.01140420 128.975508  0
0.25449503  0.00806401 31.5593728  0
;

%check(ParameterEstimates_SMP,ParameterEstimates2,
       %str(method=absolute criterion=.01),
       %str(keep=Estimate StdErr tValue Probt));
%check(ParameterEstimates_MPP,ParameterEstimates2,
       %str(method=absolute criterion=.01),
       %str(keep=Estimate StdErr tValue Probt));


/* expected OUTEST data */
data outest2;
    input _STATUS_ Mu Sigma;
datalines;
0  1.47086185    0.25449503
0  0.01140420    0.00806401
;

%check(outest_SMP,outest2,%str(method=absolute criterion=.01),
       %str(keep=_STATUS_ Mu Sigma));
%check(outest_MPP,outest2,%str(method=absolute criterion=.01),
       %str(keep=_STATUS_ Mu Sigma));


/* expected OUTSTAT data */
data outstat2;
    input _NMODELPARM_ _NESTPARM_ _NOBS_ _STATUS_ _SELECTED_
          Neg2LogLike AIC AICC BIC KS AD CvM;
    _MODEL_='Logn';
datalines;
2 2 500 0 1 1521.32447 1525.32447 1525.34862 1533.75369 0.672536
 0.314022 0.060413

;

%check(outstat_SMP,outstat2,%str(method=absolute criterion=.01),
       %str(drop=_MODEL_));
%check(outstat_MPP,outstat2,%str(method=absolute criterion=.01),
       %str(drop=_MODEL_ KS AD CvM));
